BooksEntity class

Constructors

BooksEntity({required String title, required String price, required String availability, required String image, required String link})

Properties

availability String
final
hashCode int
The hash code for this object.
no setterinherited
image String
final
final
price String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited