example/query_example
library
Functions
-
main()
→ Future<void>
-
Example of using Query with the Scraper class.
This example demonstrates how to use the Scraper class for scraping.
The difference between this example and
elements_example.dart is that elements_example.dart is intended to extract multiple elements, such as several books.